Fraction

Struct Fraction 

pub struct Fraction {
    pub numerator: i128,
    pub denominator: i128,
}

Fields

numerator: i128denominator: i128

Implementations

Source

impl Fraction

pub fn new(numerator: i128, denominator: i128) -> Result<Self, FuelError>

Creates a new fraction with the given numerator and denominator Panics if given a denominator of 0

pub fn reduce(&self) -> Self

Returns a new Fraction that is equal to this one, but simplified

pub fn to_decimal(&self) -> f64

Returns a decimal equivalent to this Fraction